@@ -3,7 +3,6 @@ import hashlib
 from threading import Thread, Lock
 import time
 from typing import Any, Callable, Awaitable
-from pydantic import BaseModel
 try:
     from pymilvus import MilvusClient, AsyncMilvusClient
     from sentence_transformers import SentenceTransformer
@@ -20,7 +19,7 @@ def getMD5(bt: bytes)->str:
 
 class Milvuser:
     def __init__(self, url:str, get_model:Callable, default_col:str, 
-                 datas_to_waits_func:Callable[[list], list],
+                 datas_to_waits_func:Callable[[list[dict]], list],
                  waits_to_vectors_func:Callable[[Any, list[Any]], Tensor],
                  user: str = "", password: str = "", db_name: str = ""):
         self.client:MilvusClient=None
@@ -75,19 +74,19 @@ class Milvuser:
                                 **kwargs
                             )
 
-    def update_insert(self, *datas:dict|BaseModel, col:str=None)->dict:
+    def update_insert(self, *datas:dict, col:str=None)->dict:
         self.init_model()
         waitvs = self.datas_to_waits_func(datas)
         vcs = self.waits_to_vectors_func(self.model, waitvs)
-        rs = [{**(data if isinstance(data, dict) else data.model_dump()), 'vector': vector} for data, vector in zip(datas, vcs)]
+        rs = [{**data, 'vector': vector} for data, vector in zip(datas, vcs)]
         self.client = self.client or self.getClient()
         return self.client.insert(col or self.default_col, rs)
     
-    def update(self, mid, data:dict|BaseModel, col:str=None)->dict:
+    def update(self, mid, data:dict, col:str=None)->dict:
         dts = self.query(ids=[mid])
         assert dts, f'数据库没有 {mid} 数据'
         dt = dts[0]
-        rt = {**dt, **(data if isinstance(data, dict) else data.model_dump())}
+        rt = {**dt, **data}
         self.client = self.client or self.getClient()
         return self.client.upsert(col or self.default_col, rt)
     
@@ -130,9 +129,15 @@ class Milvuser:
         res = self.client.delete(col or self.default_col, filter=filter, filter_params=filter_params or {}, ids=ids)
         return res
     
+    # def all_count(self, col:str=None, time_wait: float=3)->int:
+    #     self.client = self.client or self.getClient()
+    #     self.client.flush(col or self.default_col)
+    #     time.sleep(time_wait)
+    #     return self.client.get_collection_stats(col or self.default_col)['row_count']
+    
 class AMilvuser:
     def __init__(self, url:str, get_model:Callable, default_col:str,
-                 adatas_to_waits_func:Callable[[list], list],
+                 adatas_to_waits_func:Callable[[list[dict]], list],
                  awaits_to_vectors_func:Callable[[Any, list[Any]], Awaitable[Tensor]],
                  user: str = "", password: str = "", db_name: str = ""):
         self.client:AsyncMilvusClient=None
@@ -182,19 +187,19 @@ class AMilvuser:
                                     **kwargs
                                 )        
         
-    async def update_insert(self, *datas:dict|BaseModel, col:str=None)->dict:
+    async def update_insert(self, *datas:dict, col:str=None)->dict:
         self.init_model()
         waitvs = await self.adatas_to_waits_func(datas)
         vcs = await self.awaits_to_vectors_func(self.model, waitvs)
-        rs = [{**(data if isinstance(data, dict) else data.model_dump()), 'vector': vector} for data, vector in zip(datas, vcs)]
+        rs = [{**data, 'vector': vector} for data, vector in zip(datas, vcs)]
         self.client = self.client or self.getClient()
         return await self.client.insert(col or self.default_col, rs)
     
-    async def update(self, mid, data:dict|BaseModel, col:str=None)->dict:
+    async def update(self, mid, data:dict, col:str=None)->dict:
         dts = await self.query(ids=[mid])
         assert dts, f'数据库没有 {mid} 数据'
         dt = dts[0]
-        rt = {**dt, **(data if isinstance(data, dict) else data.model_dump())}
+        rt = {**dt, **data}
         self.client = self.client or self.getClient()
         return await self.client.upsert(col or self.default_col, rt)
     
@@ -236,11 +241,16 @@ class AMilvuser:
         res = await self.client.delete(col or self.default_col, filter=filter, filter_params=filter_params or {}, ids=ids)
         return res
     
+    # async def all_count(self, col:str=None, time_wait: float=3)->int:
+    #     self.client = self.client or self.getClient()
+    #     await self.client.flush(col or self.default_col)
+    #     await asyncio.sleep(time_wait)
+    #     return (await self.client.get_collection_stats(col or self.default_col))['row_count']
     
 class STMilvuser(Milvuser):
     """使用SentenceTransformer加载模型
     """
-    def __init__(self, url:str, model_name_or_path:str, default_col:str, datas_to_waits_func:Callable[[list], list], 
+    def __init__(self, url:str, model_name_or_path:str, default_col:str, datas_to_waits_func:Callable[[list[dict]], list], 
                  user: str = "", password: str = "", db_name: str = "", 
                  device:str='cpu'):
         super().__init__(url, get_model=lambda: SentenceTransformer(model_name_or_path, device=device), 
@@ -251,11 +261,10 @@ class STMilvuser(Milvuser):
 class ASTMilvuser(AMilvuser):
     """使用SentenceTransformer加载模型
     """
-    async def _awaits_to_vectors_func(self, model, ls):
-        datas = await self.adatas_to_waits_func(ls)
-        return await asyncio.to_thread(model.encode, datas)
+    async def _awaits_to_vectors_func(self, model, waits):
+        return await asyncio.to_thread(model.encode, waits)
     
-    def __init__(self, url:str, model_name_or_path:str, default_col:str, adatas_to_waits_func:Callable[[list], Awaitable[list]], 
+    def __init__(self, url:str, model_name_or_path:str, default_col:str, adatas_to_waits_func:Callable[[list[dict]], Awaitable[list]], 
                  user: str = "", password: str = "", db_name: str = "", 
                  device:str='cpu'):
         super().__init__(url, get_model=lambda: SentenceTransformer(model_name_or_path, device=device), 
@@ -270,7 +279,7 @@ class OpenaiMilvuser(Milvuser):
         datas = model.embeddings.create(input=waits, model=self.embeddings_model, dimensions=self.dimension).data
         return [data.embedding for data in datas]
         
-    def __init__(self, url:str, openai_url:str, embeddings_model:str, default_col:str, datas_to_waits_func:Callable[[list], list],
+    def __init__(self, url:str, openai_url:str, embeddings_model:str, default_col:str, datas_to_waits_func:Callable[[list[dict]], list],
                  api_key:str='EMPTY', user: str = "", password: str = "", db_name: str = "", dimensions:int=NOT_GIVEN):
         super().__init__(url, get_model=lambda: OpenAI(base_url=openai_url,api_key=api_key), 
                          default_col=default_col, datas_to_waits_func=datas_to_waits_func,
@@ -286,7 +295,7 @@ class AOpenaiMilvuser(AMilvuser):
         datas = (await model.embeddings.create(input=waits, model=self.embeddings_model, dimensions=self.dimension)).data
         return [data.embedding for data in datas]
         
-    def __init__(self, url:str, openai_url:str, embeddings_model:str, default_col:str, adatas_to_waits_func:Callable[[list], Awaitable[list]],
+    def __init__(self, url:str, openai_url:str, embeddings_model:str, default_col:str, adatas_to_waits_func:Callable[[list[dict]], Awaitable[list]],
                  api_key:str='EMPTY', user: str = "", password: str = "", db_name: str = "", dimensions:int=NOT_GIVEN):
         super().__init__(url, get_model=lambda: AsyncOpenAI(base_url=openai_url,api_key=api_key), 
                          default_col=default_col, adatas_to_waits_func=adatas_to_waits_func,
