@@ -1,11 +1,8 @@
-import subprocess
 try:
     from PIL import Image
     from moviepy.editor import VideoFileClip
 except ModuleNotFoundError:
-    subprocess.check_call(['pip','install', "moviepy", "pillow"])
-    from PIL import Image
-    from moviepy.editor import VideoFileClip
+    raise ModuleNotFoundError('pip install moviepy pillow')
     
     
 # 等比例抽帧
